| Copyright | (c) Dominik Schrempf 2020 |
|---|---|
| License | GPL-3.0-or-later |
| Maintainer | dominik.schrempf@gmail.com |
| Stability | unstable |
| Portability | portable |
| Safe Haskell | None |
| Language | Haskell2010 |
ELynx.Tree.Supported
Description
Creation date: Thu Jun 13 14:06:45 2019.
Non-negative support value
Non-negative support value.
However, non-negativity is only checked with toSupport, and negative values
can be obtained using the Num and related instances.
See also the documentation of Length.
Instances
toSupportUnsafe :: Double -> Support Source #
Do not check if support value is negative.
class Supported e where Source #
A data type that supports extraction, setting and modifying of support values.
Instances
| Supported Support Source # | |
| Supported PhyloExplicit Source # | |
Defined in ELynx.Tree.Phylogeny Methods getSup :: PhyloExplicit -> Support Source # setSup :: Support -> PhyloExplicit -> PhyloExplicit Source # modSup :: (Support -> Support) -> PhyloExplicit -> PhyloExplicit Source # | |